@@ -4,10 +4,7 @@ from prettyqt import core
 from prettyqt.qt import QtCore
 
 
-QtCore.QParallelAnimationGroup.__bases__ = (core.AnimationGroup,)
-
-
-class ParallelAnimationGroup(QtCore.QParallelAnimationGroup):
+class ParallelAnimationGroup(core.AnimationGroupMixin, QtCore.QParallelAnimationGroup):
     def set_duration(self, duration: int):
         anims = [self.animationAt(i) for i in range(len(self))]
         for anim in anims:
