@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from collections.abc import Iterator
-from typing import Callable, Literal
+from collections.abc import Callable, Iterator
+from typing import Literal
 
 from prettyqt import core, qt
 from prettyqt.qt import QtCore
@@ -137,7 +137,7 @@ class RegularExpression(QtCore.QRegularExpression):
 
     def split(self, string: str, maxsplit: int = 0):
         raise NotImplementedError()
-        # result = list()
+        # result = []
         # matches = self.global_match(string)
         # matches = list(matches)
         # if 0 < maxsplit <= len(matches):
