@@ -1,15 +1,12 @@
-# -*- coding: utf-8 -*-
-"""
-"""
-
-from qtpy import QtCore
+from __future__ import annotations
 
 from prettyqt import core
+from prettyqt.qt import QtCore
 
 
 class RegularExpressionMatchIterator(QtCore.QRegularExpressionMatchIterator):
     def __repr__(self):
-        return "RegularExpressionMatchIterator()"
+        return f"{type(self).__name__}()"
 
     def __iter__(self):
         return self
@@ -19,7 +16,7 @@ class RegularExpressionMatchIterator(QtCore.QRegularExpressionMatchIterator):
             return core.RegularExpressionMatch(self.next())
         raise StopIteration
 
-    def peek_next(self):
+    def peek_next(self) -> core.RegularExpressionMatch:
         return core.RegularExpressionMatch(self.peekNext())
 
 
