@@ -3,10 +3,7 @@
 Contains custom models
 """
 
-from .baselistmixin import BaseListMixin
-from .basemodelmixin import BaseModelMixin
 from .selectionmixin import SelectionMixin
-from .transposeproxymodel import TransposeProxyModel
 from .importlibdistributionmodel import ImportlibDistributionModel
 from .regexmatchesmodel import RegexMatchesModel
 from .columnitemmodel import ColumnItemModel, ColumnItem
@@ -17,10 +14,7 @@ from .nestedmodel import NestedModel
 from .subsequencesortfilterproxymodel import SubsequenceSortFilterProxyModel
 
 __all__ = [
-    "BaseListMixin",
-    "BaseModelMixin",
     "SelectionMixin",
-    "TransposeProxyModel",
     "ImportlibDistributionModel",
     "RegexMatchesModel",
     "ColumnItemModel",
