@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from collections.abc import Iterable, Mapping
+from collections.abc import Callable, Iterable, Mapping
 import functools
 import pathlib
-from typing import Any, Callable
+from typing import Any
 
 from prettyqt import custom_validators, custom_widgets, gui, widgets
 from prettyqt.utils import types
@@ -20,8 +20,8 @@ class DataItem:
         disabled_on=None,
     ):
         self.set_value(value)
-        self.enabled_on = [enabled_on] if enabled_on else list()
-        self.disabled_on = [disabled_on] if disabled_on else list()
+        self.enabled_on = [enabled_on] if enabled_on else []
+        self.disabled_on = [disabled_on] if disabled_on else []
         self.name = None
         self.label = label
         self.optional = optional
