@@ -1,13 +1,14 @@
-"""
-Contains the quick reference widget
-"""
+"""Contains the quick reference widget."""
+from __future__ import annotations
+
 import pathlib
 
 from prettyqt import widgets
+from prettyqt.qt import QtWidgets
 
 
 class QuickRefWidget(widgets.Widget):
-    def __init__(self, parent=None):
+    def __init__(self, parent: QtWidgets.QWidget | None = None):
         super().__init__(parent)
 
         self.resize(608, 353)
