@@ -4,10 +4,7 @@ from prettyqt import gui
 from prettyqt.qt import QtGui
 
 
-QtGui.QIntValidator.__bases__ = (gui.Validator,)
-
-
-class IntValidator(QtGui.QIntValidator):
+class IntValidator(gui.ValidatorMixin, QtGui.QIntValidator):
     def __repr__(self):
         return f"{type(self).__name__}({self.bottom()}, {self.top()})"
 
