@@ -49,10 +49,8 @@ FIND_FLAGS = bidict(
 
 FindFlagStr = Literal["backward", "case_sensitive", "whole_words"]
 
-QtGui.QTextDocument.__bases__ = (core.Object,)
 
-
-class TextDocument(QtGui.QTextDocument):
+class TextDocumentMixin(core.ObjectMixin):
     def __getitem__(self, index: int) -> gui.TextBlock:
         return gui.TextBlock(self.findBlockByNumber(index))
 
@@ -219,6 +217,10 @@ class TextDocument(QtGui.QTextDocument):
         self.setDefaultTextOption(options)
 
 
+class TextDocument(TextDocumentMixin, QtGui.QTextDocument):
+    pass
+
+
 if __name__ == "__main__":
     doc = TextDocument("This is a test\nHello")
     doc.set_default_text_option(QtGui.QTextOption())
