@@ -4,10 +4,7 @@ from prettyqt import core, gui
 from prettyqt.qt import QtGui
 
 
-QtGui.QTextObject.__bases__ = (core.Object,)
-
-
-class TextObject(QtGui.QTextObject):
+class TextObjectMixin(core.ObjectMixin):
     def __repr__(self):
         return f"{type(self).__name__}()"
 
@@ -15,6 +12,10 @@ class TextObject(QtGui.QTextObject):
         return gui.TextFormat(self.format())
 
 
+class TextObject(TextObjectMixin, QtGui.QTextObject):
+    pass
+
+
 if __name__ == "__main__":
     doc = gui.TextDocument()
     obj = TextObject(doc)
