@@ -18,7 +18,7 @@ TYPE = bidict(
 TypeStr = Literal["none", "image", "review", "editorial", "custom"]
 
 
-class PlaceContent(QtLocation.QPlaceContent):
+class PlaceContentMixin:
     def get_type(self) -> TypeStr:
         """Return the visibility of the place.
 
@@ -34,5 +34,9 @@ class PlaceContent(QtLocation.QPlaceContent):
         return location.PlaceSupplier(self.supplier())
 
 
+class PlaceContent(PlaceContentMixin, QtLocation.QPlaceContent):
+    pass
+
+
 if __name__ == "__main__":
     content = PlaceContent()
