@@ -1,7 +1,6 @@
 """Multimediawidgets module."""
 
-from .videowidgetcontrol import VideoWidgetControl
 from .videowidget import VideoWidget
 from .graphicsvideoitem import GraphicsVideoItem
 
-__all__ = ["VideoWidgetControl", "VideoWidget", "GraphicsVideoItem"]
+__all__ = ["VideoWidget", "GraphicsVideoItem"]
