@@ -11,7 +11,7 @@ from .hostaddress import HostAddress
 from .networkaddressentry import NetworkAddressEntry
 from .networkinterface import NetworkInterface
 from .networkdatagram import NetworkDatagram
-from .abstractsocket import AbstractSocket
+from .abstractsocket import AbstractSocket, AbstractSocketMixin
 from .localsocket import LocalSocket
 from .localserver import LocalServer
 from .tcpserver import TcpServer
@@ -24,6 +24,7 @@ from .networkaccessmanager import NetworkAccessManager
 __all__ = [
     "NetworkProxy",
     "AbstractSocket",
+    "AbstractSocketMixin",
     "LocalSocket",
     "HostAddress",
     "LocalServer",
