@@ -4,8 +4,5 @@ from prettyqt import widgets
 from prettyqt.qt import QtSvg
 
 
-QtSvg.QGraphicsSvgItem.__bases__ = (widgets.GraphicsObject,)
-
-
-class GraphicsSvgItem(QtSvg.QGraphicsSvgItem):
+class GraphicsSvgItem(widgets.GraphicsObjectMixin, QtSvg.QGraphicsSvgItem):
     pass
