@@ -55,24 +55,24 @@ def get_tokens_unprocessed(self, text: str, stack=("root",)):
                 else:
                     yield from action(self, m)
             pos = m.end()
-            if new_state is None:
-                break
-            # state transition
-            if isinstance(new_state, tuple):
-                for state in new_state:
-                    if state == "#pop":
-                        statestack.pop()
-                    elif state == "#push":
-                        statestack.append(statestack[-1])
-                    else:
-                        statestack.append(state)
-            elif isinstance(new_state, int):
-                # pop
-                del statestack[new_state:]
-            elif new_state == "#push":
-                statestack.append(statestack[-1])
-            else:
-                assert False, f"wrong state def: {new_state!r}"
+            match new_state:
+                case None:
+                    break
+                case tuple():
+                    for state in new_state:
+                        match state:
+                            case "#pop":
+                                statestack.pop()
+                            case "#push":
+                                statestack.append(statestack[-1])
+                            case _:
+                                statestack.append(state)
+                case int():
+                    del statestack[new_state:]
+                case "#push":
+                    statestack.append(statestack[-1])
+                case _:
+                    assert False, f"wrong state def: {new_state!r}"
             statetokens = tokendefs[statestack[-1]]
             break
         else:
@@ -195,22 +195,23 @@ class PygmentsHighlighter(gui.SyntaxHighlighter):
             return result
         for key, value in token_style.items():
             if value:
-                if key == "color":
-                    result.set_foreground_color(self._get_brush(value))
-                elif key == "bgcolor":
-                    result.set_background_color(self._get_brush(value))
-                elif key == "bold":
-                    result.set_font_weight("bold")
-                elif key == "italic":
-                    result.setFontItalic(True)
-                elif key == "underline":
-                    result.set_underline_style("single")
-                elif key == "sans":
-                    result.set_font_style_hint("sans_serif")
-                elif key == "roman":
-                    result.set_font_style_hint("serif")
-                elif key == "mono":
-                    result.set_font_style_hint("typewriter")
+                match key:
+                    case "color":
+                        result.set_foreground_color(self._get_brush(value))
+                    case "bgcolor":
+                        result.set_background_color(self._get_brush(value))
+                    case "bold":
+                        result.set_font_weight("bold")
+                    case "italic":
+                        result.setFontItalic(True)
+                    case "underline":
+                        result.set_underline_style("single")
+                    case "sans":
+                        result.set_font_style_hint("sans_serif")
+                    case "roman":
+                        result.set_font_style_hint("serif")
+                    case "mono":
+                        result.set_font_style_hint("typewriter")
         return result
 
     @functools.cache
