@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from collections.abc import Generator
-from typing import Any, Callable
+from collections.abc import Callable, Generator
+from typing import Any
 
 
 class PrettyPrinter:
