@@ -4,10 +4,11 @@ from prettyqt import widgets
 from prettyqt.qt import QtWidgets
 
 
-QtWidgets.QCommonStyle.__bases__ = (widgets.Style,)
+class CommonStyleMixin(widgets.StyleMixin):
+    pass
 
 
-class CommonStyle(QtWidgets.QCommonStyle):
+class CommonStyle(CommonStyleMixin, QtWidgets.QCommonStyle):
     pass
 
 
