@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from collections.abc import Iterator, Sequence
-from typing import Callable, Literal
+from collections.abc import Callable, Iterator, Sequence
+from typing import Literal
 
 from prettyqt import constants, core, widgets
 from prettyqt.qt import QtCore, QtWidgets
@@ -76,11 +76,8 @@ RoleStr = Literal[
     "reset",
 ]
 
-QtWidgets.QDialogButtonBox.__bases__ = (widgets.Widget,)
-
-
-class DialogButtonBox(QtWidgets.QDialogButtonBox):
 
+class DialogButtonBox(widgets.WidgetMixin, QtWidgets.QDialogButtonBox):
     button_clicked = core.Signal(str)
 
     def __init__(self, *args, **kwargs):
