@@ -4,13 +4,14 @@ from prettyqt import core
 from prettyqt.qt import QtWidgets
 
 
-QtWidgets.QGraphicsEffect.__bases__ = (core.Object,)
-
-
-class GraphicsEffect(QtWidgets.QGraphicsEffect):
+class GraphicsEffectMixin(core.ObjectMixin):
     def serialize_fields(self):
         return dict(enabled=self.isEnabled())
 
     def __setstate__(self, state):
         super().__setstate__(state)
         self.setEnabled(state["enabled"])
+
+
+class GraphicsEffect(GraphicsEffectMixin, QtWidgets.QGraphicsEffect):
+    pass
