@@ -3,6 +3,10 @@ from __future__ import annotations
 from prettyqt.qt import QtWidgets
 
 
-class GraphicsLayoutItem(QtWidgets.QGraphicsLayoutItem):
+class GraphicsLayoutItemMixin:
     def __repr__(self):
         return f"{type(self).__name__}()"
+
+
+class GraphicsLayoutItem(GraphicsLayoutItemMixin, QtWidgets.QGraphicsLayoutItem):
+    pass
