@@ -1,18 +1,10 @@
-# -*- coding: utf-8 -*-
-"""
-@author: Philipp Temminghoff
-"""
+from __future__ import annotations
 
-from qtpy import QtWidgets, QtGui
-
-from prettyqt import widgets, core, gui
+from prettyqt import core, gui, widgets
+from prettyqt.qt import QtGui, QtWidgets
 
 
-QtWidgets.QKeySequenceEdit.__bases__ = (widgets.Widget,)
-
-
-class KeySequenceEdit(QtWidgets.QKeySequenceEdit):
-
+class KeySequenceEdit(widgets.WidgetMixin, QtWidgets.QKeySequenceEdit):
     value_changed = core.Signal(QtGui.QKeySequence)
 
     def __init__(self, *args, **kwargs):
@@ -20,7 +12,7 @@ class KeySequenceEdit(QtWidgets.QKeySequenceEdit):
         self.keySequenceChanged.connect(self.value_changed)
 
     def __repr__(self):
-        return f"KeySequenceEdit({self.get_value()})"
+        return f"{type(self).__name__}({self.get_value()!r})"
 
     def set_value(self, value: str):
         seq = gui.KeySequence.fromString(value)
@@ -37,4 +29,4 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = KeySequenceEdit()
     widget.show()
-    app.exec_()
+    app.main_loop()
