@@ -1,17 +1,14 @@
 from __future__ import annotations
 
-from collections.abc import Iterator
-from typing import Any, Callable
+from collections.abc import Callable, Iterator
+from typing import Any
 
 from prettyqt import core, gui, iconprovider, widgets
 from prettyqt.qt import QtWidgets
 from prettyqt.utils import types
 
 
-QtWidgets.QMenu.__bases__ = (widgets.Widget,)
-
-
-class Menu(QtWidgets.QMenu):
+class MenuMixin(widgets.WidgetMixin):
     def __init__(
         self,
         title: str = "",
@@ -140,6 +137,10 @@ class Menu(QtWidgets.QMenu):
         return action
 
 
+class Menu(MenuMixin, QtWidgets.QMenu):
+    pass
+
+
 if __name__ == "__main__":
     app = widgets.app()
     menu = Menu("1")
