@@ -18,10 +18,8 @@ SWIPE_DIRECTION = bidict(
 HorizontalDirectionStr = Literal["none", "left", "right"]
 VerticalDirectionStr = Literal["none", "up", "down"]
 
-QtWidgets.QSwipeGesture.__bases__ = (widgets.Gesture,)
 
-
-class SwipeGesture(QtWidgets.QSwipeGesture):
+class SwipeGestureMixin(widgets.GestureMixin):
     def get_horizontal_direction(self) -> HorizontalDirectionStr:
         """Return horizontal direction of the gesture.
 
@@ -39,6 +37,10 @@ class SwipeGesture(QtWidgets.QSwipeGesture):
         return SWIPE_DIRECTION.inverse[self.verticalDirection()]
 
 
+class SwipeGesture(SwipeGestureMixin, QtWidgets.QSwipeGesture):
+    pass
+
+
 if __name__ == "__main__":
     from prettyqt import widgets
 
