@@ -7,10 +7,7 @@ from prettyqt.qt import QtWidgets
 from prettyqt.utils import types
 
 
-QtWidgets.QToolBox.__bases__ = (widgets.Frame,)
-
-
-class ToolBox(QtWidgets.QToolBox):
+class ToolBox(widgets.FrameMixin, QtWidgets.QToolBox):
     def __getitem__(self, index: int | str) -> QtWidgets.QWidget:
         if isinstance(index, int):
             return self.widget(index)
@@ -24,7 +21,7 @@ class ToolBox(QtWidgets.QToolBox):
         self.removeItem(index)
 
     def serialize_fields(self):
-        children = list()
+        children = []
         for i, widget in enumerate(self.get_children()):
             dct = dict(
                 widget=widget,
