@@ -102,10 +102,7 @@ TEXT_FORMATS = bidict(
 TextFormatStr = Literal["rich", "plain", "auto", "markdown"]
 
 
-QtWidgets.QWizard.__bases__ = (widgets.Dialog,)
-
-
-class Wizard(QtWidgets.QWizard):
+class WizardMixin(widgets.DialogMixin):
     def __getitem__(self, key: int) -> QtWidgets.QWizardPage:
         p = self.page(key)
         if p is None:
@@ -286,6 +283,10 @@ class Wizard(QtWidgets.QWizard):
         return self.testOption(WIZARD_OPTIONS[option])
 
 
+class Wizard(WizardMixin, QtWidgets.QWizard):
+    pass
+
+
 if __name__ == "__main__":
     app = widgets.app()
     dlg = Wizard()
